struct ParsedChild {
rel: Rel,
field_count: usize,
}Expand description
A child relation that has already been converted to a
proto Rel, paired with its own output field count.
Fields
rel: Relfield_count: usizeAuto Trait Implementations
impl !Freeze for ParsedChild
impl RefUnwindSafe for ParsedChild
impl Send for ParsedChild
impl Sync for ParsedChild
impl Unpin for ParsedChild
impl UnsafeUnpin for ParsedChild
impl UnwindSafe for ParsedChild