TreeBuilder

Struct TreeBuilder 

pub struct TreeBuilder<'a> {
    current: Option<RelationNode<'a>>,
    completed: Vec<RelationNode<'a>>,
}

Fields

current: Option<RelationNode<'a>>completed: Vec<RelationNode<'a>>

Implementations

Source

impl<'a> TreeBuilder<'a>

pub fn get_at_depth(&mut self, depth: usize) -> Option<&mut RelationNode<'a>>

Traverse down the tree, always taking the last child at each level, until reaching the specified depth.

pub fn add_line( &mut self, depth: usize, node: LineNode<'a>, ) -> Result<(), ParseError>

pub fn finish(&mut self) -> Vec<RelationNode<'a>>

End of input - move any remaining nodes from stack to completed and return any trees in progress. Resets the builder to its initial state (empty) Move any remaining nodes from stack to completed